@@ -73,6 +73,7 @@ def request(token,
 def get_updates(token: str,
                 offset: int = 0,
                 limit: int = 100,
+                timeout: int = 0,
                 allowed_updates: list = []) -> List[Update]:
     """Make getUpdate request to telegram API. Return list of updates"""
 
@@ -82,7 +83,9 @@ def get_updates(token: str,
         data={
             'offset': offset + 1,
             'limit': limit,
-            'allowed_updates': allowed_updates},
+            'allowed_updates': allowed_updates,
+            'timeout': timeout
+            },
         excpect='update'
         )
     return updates
@@ -1309,7 +1312,9 @@ def edit_message_text(token: str,
             'inline_message_id': inline_message_id,
             'parse_mode': parse_mode,
             'disable_web_page_preview': disable_web_page_preview,
-            'reply_markup': reply_markup.unfold()
+            'reply_markup': (reply_markup.unfold()
+                             if reply_markup is not None
+                             else None)
         }
     )
 
